/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();
};

MainWindow::MainWindow()
{
   setMinimumSize(500, 600);

   QLabel *label = new QLabel();
   label->setText("Label with a Frame");
   label->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
   label->setFrameStyle(QFrame::Panel | QFrame::Raised);
   label->setLineWidth(3);
   label->setMinimumSize(25, 30);

   auto *frame1 = new QFrame();
   frame1->setFrameStyle(QFrame::Box);
   frame1->setLineWidth(3);
   frame1->setMidLineWidth(2);
   frame1->setMinimumSize(25, 30);

   auto *frame2 = new QFrame(this);
   frame2->setFrameStyle(QFrame::Box | QFrame::Raised);
   frame2->setLineWidth(3);
   frame2->setMidLineWidth(2);
   frame2->setMinimumSize(25, 30);

   auto *frame3 = new QFrame(this);
   frame3->setFrameStyle(QFrame::Box | QFrame::Sunken);
   frame3->setLineWidth(3);
   frame3->setMidLineWidth(2);
   frame3->setMinimumSize(25, 30);

   QPushButton *pb_close = new QPushButton();
   pb_close->setText("Close");

   QGridLayout *grid = new QGridLayout();
   grid->setVerticalSpacing(20);

   grid->addWidget(label);
   grid->addWidget(frame1);
   grid->addWidget(frame2);
   grid->addWidget(frame3);

   QHBoxLayout *layout = new QHBoxLayout();
   layout->addStretch();
   layout->addWidget(pb_close);
   layout->addStretch();

   QVBoxLayout *layout_main = new QVBoxLayout(this);
   layout_main->addLayout(grid);
   layout_main->addSpacing(25);
   layout_main->addLayout(layout);

   connect(pb_close, &QPushButton::clicked, this, &QWidget::close);
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}
